@@ -256,6 +256,7 @@ class CustomFalconReader:
                     "date": start_date,
                     "data": payload,
                 }
+                self.start = 0
             else:
                 print(
                     f"No data for endpoint {self._config['endpoint_name']} for date : {start_date}"
@@ -299,7 +300,6 @@ class CustomFalconReaderV2:
             channel_ids = {}
             for item in response_data.get("items", []):
                 channel_ids[item["uuid"]] = item["name"]
-            # print(len(channel_ids))
             return channel_ids
 
         raise ConnectionError(
@@ -343,7 +343,6 @@ class CustomFalconReaderV2:
                         content_id
                     )
             endpoint_url = response_data.get("next", {"href": None}).get("href")
-        print(content_ids_by_channel_id)
         return content_ids_by_channel_id
 
     def _get_insights_request_id(
@@ -417,7 +416,6 @@ class CustomFalconReaderV2:
     def _normalize_data(dataset: dict, network: str, channel_ids: dict):
         normalized_data = []
         for metric, data_items in dataset.items():
-            # print(metric)
             for data_item in data_items:
                 data_item[f"{metric}"] = data_item.pop("value")
                 data_item["network"] = network
@@ -495,9 +493,10 @@ class CustomFalconReaderV2:
             if len(payload) > 0:
                 yield {
                     "networks": network,
-                    "date": date.replace("-", ""),
+                    "date": date,
                     "data": payload,
                 }
+                self.start = 0
                 self.is_success()
             else:
                 self.not_success()
