@@ -30,10 +30,10 @@ class CustomS3JsonWriter:
             - pull from a specific date, we overwrite all that days data in the buckets.
             - this way, we ensure all data is original and in its most updated state.
         """
-        dimension = json_data["dimension"]
+        # dimension = json_data["dimension"]
         date = json_data["date"].replace("-", "")
         dataset = json_data["data"]
-        # metric = json_data["metric"]
-        key_path = f"{self.file_path}/{dimension}/{date}.json"
+        business = json_data["business"]
+        key_path = f"{self.file_path}/{business}/{date}.json"
         print(f"Writing data to {key_path}.")
         self.s3_resource.Object(self.bucket, key_path).put(Body=json.dumps(dataset))
