@@ -1,3 +1,4 @@
+# pylint: disable=ungrouped-imports
 import os
 import warnings
 from datetime import datetime
@@ -108,8 +109,8 @@ def advanced_writer(*, dataframe, output_data_config: dict = None, **kwargs):
         dataframe_writer.parquet(output_path)
     else:
         raise Exception(
-            "Output type = {OUTPUT_TYPE} not supported. "
-            "Only support csv and json at current.".format(OUTPUT_TYPE=output_type)
+            f"Output type = {output_type} not supported. "
+            "Only support csv and json at current."
         )
 
 
@@ -189,7 +190,7 @@ def advanced_writer_w_custom_partition_naming(
                     "output_path": os.path.join(output_path, partition),
                     "output_type": output_type,
                 },
-                **kwargs
+                **kwargs,
             )
     else:
         advanced_writer(dataframe, output_data_config=output_data_config, **kwargs)
